from setuptools import setup

setup(name='bs_solevaluator',
      version='0.1',
      description='Solution evaluator for the Benchmark Set of the ORSP (by Leeftink and Hans 2016).',
      author='Panagiotis Giannakoulias',
      author_email='panosgia87@hotmail.com',
      license='MIT',
      packages=['bs_solevaluator'],
      zip_safe=False)